C$$$   SUBPROGRAM DOCUMENTATION BLOCK
C
C SUBPROGRAM:     M_CVWFTAT    CONVERTS YYYYMMDD_HHMM TO YYDDDHHMM        
C   PRGMMR:  BARTH, M.         ORG: FSL          DATE: 99-12-15
C
C ABSTRACT: THIS ROUTINE CONVERTS A WFOA-STYLE FILENAME (YYYYMMDD_HHMM)
C   INTO THE CORRESPONDING FSL-STYLE ATIME FILENAME (YYDDDHHMM).
C
C PROGRAM HISTORY LOG:
C   01-08-01  M. BARTH    ORIGINAL PROGRAM (COPIED FROM MSAS)
C   08-06-13  L. BENJAMIN CHANGED "MADISCON" INCLUDE TO 
C                         "INTQC1CON1"
C
C USAGE:    CALL M_CVWFTAT(WFOANAME,ATIME,ISTATUS)
C   INPUT ARGUMENT LIST:
C     WFOANAME - C  THE WFOA-STYLE FILENAME (YYYYMMDD_HHMM)
C
C   OUTPUT ARGUMENT LIST:
C     ATIME    - C  THE FSL-STYLE ATIME FILENAME (YYDDDHHMM)
C     ISTATUS  - I  RETURNED PROGRAM STATUS 
C
C SUBPROGRAMS CALLED:
C     UNIQUE:  M_GTI4TM, M_MKFNAM
C
C REMARKS: NONE
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN + EXTENSIONS
C   MACHINE: UNIX
C
C$$$
      SUBROUTINE M_CVWFTAT (WFOANAME,ATIME,ISTATUS)

      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'

      CHARACTER*(*) WFOANAME,ATIME
      INTEGER M_GTI4TM,I4TIME,ISTATUS,NYEAR,MONTH,NDAY,NHOUR,NMIN

      ISTATUS = FAILURE_P

      READ(WFOANAME,1,ERR=900)NYEAR,MONTH,NDAY,NHOUR,NMIN
 1    FORMAT(2X,I2,I2,I2,1X,I2,I2)
      I4TIME = M_GTI4TM(NYEAR,MONTH,NDAY,NHOUR,NMIN,0,ISTATUS)
      IF(ISTATUS.EQ.SUCCESS_P)CALL M_MKFNAM(I4TIME,ATIME,ISTATUS)

 900  RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
